@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-  2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,
-  2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 2000-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -25,7 +23,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <syslog.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 #include "extern.h"
 
 #ifdef HAVE_SECURITY_PAM_APPL_H
@@ -314,7 +312,7 @@ pam_pass (const char *passwd, struct credentials *pcred)
 }
 
 void
-pam_end_login (struct credentials * pcred _GL_UNUSED_PARAMETER)
+pam_end_login (struct credentials * pcred MAYBE_UNUSED)
 {
   int error;
 
