@@ -1,5 +1,5 @@
 /* printif.c -- print an interface configuration
-  Copyright (C) 2001-2020 Free Software Foundation, Inc.
+  Copyright (C) 2001-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -46,7 +46,7 @@
 #include <arpa/inet.h>
 #include "ifconfig.h"
 #include "xalloc.h"
-#include <unused-parameter.h>
+#include <attribute.h>
 
 FILE *ostream;			/* Either stdout or stderror.  */
 int column_stdout;		/* The column position of the cursor on stdout.  */
@@ -118,7 +118,7 @@ struct format_handle format_handles[] = {
 /* Various helper functions to get the job done.  */
 
 void
-put_char (format_data_t form _GL_UNUSED_PARAMETER, char c)
+put_char (format_data_t form MAYBE_UNUSED, char c)
 {
   switch (c)
     {
@@ -146,7 +146,7 @@ put_string (format_data_t form, const char *s)
 }
 
 void
-put_int (format_data_t form _GL_UNUSED_PARAMETER,
+put_int (format_data_t form MAYBE_UNUSED,
 	 int argc, char *argv[], int nr)
 {
   char *fmt;
@@ -203,7 +203,7 @@ put_int (format_data_t form _GL_UNUSED_PARAMETER,
 }
 
 void
-put_ulong (format_data_t form _GL_UNUSED_PARAMETER,
+put_ulong (format_data_t form MAYBE_UNUSED,
 	   int argc, char *argv[], unsigned long value)
 {
   char *fmt;
@@ -344,8 +344,8 @@ put_flags (format_data_t form, int argc, char *argv[], int flags)
 }
 
 void
-put_flags_short (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-		 char *argv[] _GL_UNUSED_PARAMETER, int flags)
+put_flags_short (format_data_t form, int argc MAYBE_UNUSED,
+		 char *argv[] MAYBE_UNUSED, int flags)
 {
   char buf[IF_FORMAT_FLAGS_BUFSIZE];
   if_format_flags (flags, buf, sizeof buf);
@@ -376,9 +376,9 @@ format_handler (const char *name, format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_nothing (format_data_t form _GL_UNUSED_PARAMETER,
-	    int argc _GL_UNUSED_PARAMETER,
-	    char *argv[] _GL_UNUSED_PARAMETER)
+fh_nothing (format_data_t form MAYBE_UNUSED,
+	    int argc MAYBE_UNUSED,
+	    char *argv[] MAYBE_UNUSED)
 {
 }
 
@@ -437,15 +437,15 @@ fh_foreachformat (format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_newline (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	    char *argv[] _GL_UNUSED_PARAMETER)
+fh_newline (format_data_t form, int argc MAYBE_UNUSED,
+	    char *argv[] MAYBE_UNUSED)
 {
   put_char (form, '\n');
 }
 
 void
-fh_tabulator (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	      char *argv[] _GL_UNUSED_PARAMETER)
+fh_tabulator (format_data_t form, int argc MAYBE_UNUSED,
+	      char *argv[] MAYBE_UNUSED)
 {
   put_char (form, '\t');
 }
@@ -612,14 +612,14 @@ fh_error (format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_progname (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	     char *argv[] _GL_UNUSED_PARAMETER)
+fh_progname (format_data_t form, int argc MAYBE_UNUSED,
+	     char *argv[] MAYBE_UNUSED)
 {
   put_string (form, program_name);
 }
 
 void
-fh_exit (format_data_t form _GL_UNUSED_PARAMETER,
+fh_exit (format_data_t form MAYBE_UNUSED,
 	 int argc, char *argv[])
 {
   int err = 0;
@@ -631,8 +631,8 @@ fh_exit (format_data_t form _GL_UNUSED_PARAMETER,
 }
 
 void
-fh_name (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	 char *argv[] _GL_UNUSED_PARAMETER)
+fh_name (format_data_t form, int argc MAYBE_UNUSED,
+	 char *argv[] MAYBE_UNUSED)
 {
   put_string (form, form->name);
 }
@@ -644,8 +644,8 @@ fh_index_query (format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_index (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	  char *argv[] _GL_UNUSED_PARAMETER)
+fh_index (format_data_t form, int argc MAYBE_UNUSED,
+	  char *argv[] MAYBE_UNUSED)
 {
   int indx = if_nametoindex (form->name);
 
@@ -928,8 +928,8 @@ fh_media_query (format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_media (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	  char *argv[] _GL_UNUSED_PARAMETER)
+fh_media (format_data_t form, int argc MAYBE_UNUSED,
+	  char *argv[] MAYBE_UNUSED)
 {
   /* Must be overridden by a system dependent implementation.  */
   put_string (form, "(not known)");
@@ -945,8 +945,8 @@ fh_status_query (format_data_t form, int argc, char *argv[])
 }
 
 void
-fh_status (format_data_t form, int argc _GL_UNUSED_PARAMETER,
-	   char *argv[] _GL_UNUSED_PARAMETER)
+fh_status (format_data_t form, int argc MAYBE_UNUSED,
+	   char *argv[] MAYBE_UNUSED)
 {
   /* Must be overridden by a system dependent implementation.  */
   put_string (form, "(not known)");
