@@ -1,7 +1,5 @@
 /* shishi.c -- functions to use kerberos V with shishi
-  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013,
-  2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software
-  Foundation, Inc.
+  Copyright (C) 2005-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
