@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012,
-  2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software
-  Foundation, Inc.
+  Copyright (C) 1993-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -70,7 +67,7 @@
 
 #include <config.h>
 
-#include "unused-parameter.h"
+#include "attribute.h"
 
 #if defined AUTHENTICATION
 # include <stdio.h>
@@ -665,7 +662,7 @@ auth_finished (TN_Authenticator * ap, int result)
 }
 
 static void
-auth_intr (int sig _GL_UNUSED_PARAMETER)
+auth_intr (int sig MAYBE_UNUSED)
 {
   auth_finished (0, AUTH_REJECT);
 }
