@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
-  Inc.
+  Copyright (C) 1995-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -59,7 +56,7 @@
 #include <time.h>
 #include <signal.h>
 #include <stdio.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 #include "talk.h"
 
 #define MSG_INTERVAL 4
@@ -68,7 +65,7 @@ char *current_state;
 int current_line = 0;
 
 static void
-disp_msg (int sig _GL_UNUSED_PARAMETER)
+disp_msg (int sig MAYBE_UNUSED)
 {
   message (current_state);
 }
